abacusai.llm_artifact_conversation — AbacusAI documentation

# abacusai.llm_artifact_conversation

## Classes

`LlmArtifactConversation` | LLM Artifact Conversation

## Module Contents

class abacusai.llm_artifact_conversation.LlmArtifactConversation(client, deploymentConversationId=None, llmArtifactId=None, deploymentConversationName=None, externalApplicationId=None, createdAt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  LLM Artifact Conversation

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - deploymentConversationId (id) – The ID of the deployment conversation

    - llmArtifactId (id) – The ID of the LLM artifact

    - deploymentConversationName (str) – The name of the conversation

    - externalApplicationId (str) – The external application ID

    - createdAt (str) – The creation timestamp

  deployment_conversation_id = None
  llm_artifact_id = None
  deployment_conversation_name = None
  external_application_id = None
  created_at = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict